pip\_chill package
==================

Submodules
----------

pip\_chill.cli module
---------------------

.. automodule:: pip_chill.cli
   :members:
   :undoc-members:
   :show-inheritance:

pip\_chill.pip\_chill module
----------------------------

.. automodule:: pip_chill.pip_chill
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pip_chill
   :members:
   :undoc-members:
   :show-inheritance:
